@@ -1,7 +1,9 @@
-# Copyright: 2005-2011 Gentoo Foundation
+# Copyright 2005-2014 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 # Author(s): Brian Harring (ferringb@gentoo.org)
 
+from __future__ import unicode_literals
+
 from portage.cache import fs_template
 from portage.cache import cache_errors
 import errno
@@ -11,18 +13,14 @@ import sys
 import os as _os
 from portage import os
 from portage import _encodings
-from portage import _unicode_decode
 from portage import _unicode_encode
 from portage.exception import InvalidData
 from portage.versions import _pkg_str
 
 if sys.hexversion >= 0x3000000:
+	# pylint: disable=W0622
 	long = int
 
-# Coerce to unicode, in order to prevent TypeError when writing
-# raw bytes to TextIOWrapper with python2.
-_setitem_fmt = _unicode_decode("%s=%s\n")
-
 class database(fs_template.FsBased):
 
 	autocommits = True
@@ -42,11 +40,10 @@ class database(fs_template.FsBased):
 		# Don't use os.path.join, for better performance.
 		fp = self.location + _os.sep + cpv
 		try:
-			myf = io.open(_unicode_encode(fp,
+			with io.open(_unicode_encode(fp,
 				encoding=_encodings['fs'], errors='strict'),
 				mode='r', encoding=_encodings['repo.content'],
-				errors='replace')
-			try:
+				errors='replace') as myf:
 				lines = myf.read().split("\n")
 				if not lines[-1]:
 					lines.pop()
@@ -56,8 +53,6 @@ class database(fs_template.FsBased):
 					# that uses mtime mangling.
 					d['_mtime_'] = _os.fstat(myf.fileno())[stat.ST_MTIME]
 				return d
-			finally:
-				myf.close()
 		except (IOError, OSError) as e:
 			if e.errno != errno.ENOENT:
 				raise cache_errors.CacheCorruption(cpv, e)
@@ -96,7 +91,10 @@ class database(fs_template.FsBased):
 				v = values.get(k)
 				if not v:
 					continue
-				myf.write(_setitem_fmt % (k, v))
+				# NOTE: This format string requires unicode_literals, so that
+				# k and v are coerced to unicode, in order to prevent TypeError
+				# when writing raw bytes to TextIOWrapper with Python 2.
+				myf.write("%s=%s\n" % (k, v))
 		finally:
 			myf.close()
 		self._ensure_access(fp)
